package com.mdd.admin.service.impl;

import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONReader;
import com.alibaba.fastjson2.JSONWriter;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Assert;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.mdd.admin.service.IAlbumsService;
import com.mdd.admin.validate.album.AlbumCateValidate;
import com.mdd.admin.validate.album.AlbumSearchValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.vo.album.AlbumCateVo;
import com.mdd.admin.vo.album.AlbumVo;
import com.mdd.common.config.GlobalConfig;
import com.mdd.common.core.PageResult;
import com.mdd.common.entity.album.Album;
import com.mdd.common.entity.album.AlbumCate;
import com.mdd.common.mapper.album.AlbumCateMapper;
import com.mdd.common.mapper.album.AlbumMapper;
import com.mdd.common.util.ConfigUtils;
import com.mdd.common.util.ListUtils;
import com.mdd.common.util.StringUtils;
import com.mdd.common.util.TimeUtils;
import com.mdd.common.util.ToolUtils;
import com.mdd.common.util.UrlUtils;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
import javax.annotation.Resource;
import org.springframework.beans.BeanUtils;
import org.springframework.stereotype.Service;

@Service
public class AlbumsServiceImpl implements IAlbumsService {
   @Resource
   AlbumMapper albumMapper;
   @Resource
   AlbumCateMapper albumCateMapper;

   public PageResult<AlbumVo> albumList(PageValidate pageValidate, AlbumSearchValidate searchValidate) {
      Integer page = pageValidate.getPageNo();
      Integer limit = pageValidate.getPageSize();
      QueryWrapper<Album> queryWrapper = new QueryWrapper();
      ((QueryWrapper)queryWrapper.select(Album.class, (info) -> {
         return !info.getColumn().equals("type") && !info.getColumn().equals("aid") && !info.getColumn().equals("uid") && !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("is_delete", 0)).orderByDesc("id");
      if (StringUtils.isNotNull(searchValidate.getCid())) {
         queryWrapper.eq("cid", searchValidate.getCid());
      }

      this.albumMapper.setSearch(queryWrapper, searchValidate, new String[]{"=:type:int", "like:keyword@name:str"});
      IPage<Album> iPage = this.albumMapper.selectPage(new Page((long)page, (long)limit), queryWrapper);
      String engine = ConfigUtils.get("storage", "default", "local");
      engine = engine.equals("") ? "local" : engine;
      List<AlbumVo> list = new ArrayList();
      Iterator var9 = iPage.getRecords().iterator();

      while(var9.hasNext()) {
         Album album = (Album)var9.next();
         AlbumVo vo = new AlbumVo();
         BeanUtils.copyProperties(album, vo);
         if (engine.equals("local")) {
            vo.setPath(GlobalConfig.publicPrefix + "/" + album.getUri());
         } else {
            vo.setPath(album.getUri());
         }

         vo.setUri(UrlUtils.toAbsoluteUrl(album.getUri()));
         vo.setSize(ToolUtils.storageUnit(album.getSize()));
         vo.setCreateTime(TimeUtils.timestampToDate(album.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(album.getUpdateTime()));
         list.add(vo);
      }

      return PageResult.iPageHandle(iPage.getTotal(), iPage.getCurrent(), iPage.getSize(), list);
   }

   public void albumRename(Integer id, String name) {
      Album album = (Album)this.albumMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "name"}).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(album, "文件丢失！", new Object[0]);
      album.setName(name);
      album.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.albumMapper.updateById(album);
   }

   public void albumMove(List<Integer> ids, Integer cid) {
      List<Album> albums = this.albumMapper.selectList((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "name"}).in("id", ids)).eq("is_delete", 0));
      Assert.notNull(albums, "文件丢失！", new Object[0]);
      if (cid > 0) {
         Assert.notNull(this.albumCateMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).eq("id", cid)).eq("is_delete", 0)), "类目已不存在！", new Object[0]);
      }

      Iterator var4 = albums.iterator();

      while(var4.hasNext()) {
         Album album = (Album)var4.next();
         album.setCid(cid);
         album.setUpdateTime(System.currentTimeMillis() / 1000L);
         this.albumMapper.updateById(album);
      }

   }

   public Integer albumAdd(Map<String, String> params) {
      String name = (String)params.get("name");
      if (name.length() >= 100) {
         name = name.substring(0, 99);
      }

      Album album = new Album();
      album.setCid(Integer.parseInt(params.get("cid") == null ? "0" : (String)params.get("cid")));
      album.setAid(Integer.parseInt(params.get("aid") == null ? "0" : (String)params.get("aid")));
      album.setUid(Integer.parseInt(params.get("uid") == null ? "0" : (String)params.get("uid")));
      album.setType(Integer.parseInt((String)params.get("type")));
      album.setName(name);
      album.setExt((String)params.get("ext"));
      album.setUri((String)params.get("url"));
      album.setSize(Long.parseLong((String)params.get("size")));
      album.setCreateTime(System.currentTimeMillis() / 1000L);
      album.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.albumMapper.insert(album);
      return album.getId();
   }

   public void albumDel(List<Integer> ids) {
      List<Album> albums = this.albumMapper.selectList((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "name"}).in("id", ids)).eq("is_delete", 0));
      Assert.notNull(albums, "文件丢失！", new Object[0]);
      Iterator var3 = albums.iterator();

      while(var3.hasNext()) {
         Album album = (Album)var3.next();
         album.setIsDelete(1);
         album.setDeleteTime(System.currentTimeMillis() / 1000L);
         this.albumMapper.updateById(album);
      }

   }

   public JSONArray cateList(AlbumSearchValidate searchValidate) {
      QueryWrapper<AlbumCate> queryWrapper = new QueryWrapper();
      ((QueryWrapper)queryWrapper.select(AlbumCate.class, (info) -> {
         return !info.getColumn().equals("is_delete") && !info.getColumn().equals("delete_time");
      }).eq("is_delete", 0)).orderByDesc("id");
      if (StringUtils.isNotNull(searchValidate.getType()) && searchValidate.getType() > 0) {
         queryWrapper.eq("type", searchValidate.getType());
      }

      if (StringUtils.isNotNull(searchValidate.getKeyword()) && StringUtils.isNotEmpty(searchValidate.getKeyword())) {
         queryWrapper.like("name", searchValidate.getKeyword());
      }

      List<AlbumCate> albumCateList = this.albumCateMapper.selectList(queryWrapper);
      List<AlbumCateVo> lists = new LinkedList();
      Iterator var5 = albumCateList.iterator();

      while(var5.hasNext()) {
         AlbumCate albumCate = (AlbumCate)var5.next();
         AlbumCateVo vo = new AlbumCateVo();
         BeanUtils.copyProperties(albumCate, vo);
         vo.setCreateTime(TimeUtils.timestampToDate(albumCate.getCreateTime()));
         vo.setUpdateTime(TimeUtils.timestampToDate(albumCate.getUpdateTime()));
         lists.add(vo);
      }

      JSONArray jsonArray = JSONArray.parseArray(JSONArray.toJSONString(lists, new JSONWriter.Feature[0]), new JSONReader.Feature[0]);
      return ListUtils.listToTree(jsonArray, "id", "pid", "children");
   }

   public void cateAdd(AlbumCateValidate cateValidate) {
      AlbumCate albumCate = new AlbumCate();
      albumCate.setType(cateValidate.getType());
      albumCate.setPid(cateValidate.getPid());
      albumCate.setName(cateValidate.getName());
      albumCate.setCreateTime(System.currentTimeMillis() / 1000L);
      albumCate.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.albumCateMapper.insert(albumCate);
   }

   public void cateRename(Integer id, String name) {
      AlbumCate albumCate = (AlbumCate)this.albumCateMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "name"}).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(albumCate, "分类已不存在！", new Object[0]);
      albumCate.setName(name);
      albumCate.setUpdateTime(System.currentTimeMillis() / 1000L);
      this.albumCateMapper.updateById(albumCate);
   }

   public void cateDel(Integer id) {
      AlbumCate albumCate = (AlbumCate)this.albumCateMapper.selectOne((Wrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "name"}).eq("id", id)).eq("is_delete", 0));
      Assert.notNull(albumCate, "分类已不存在！", new Object[0]);
      Assert.isNull(this.albumMapper.selectOne((Wrapper)((QueryWrapper)((QueryWrapper)(new QueryWrapper()).select(new String[]{"id", "cid", "name"}).eq("cid", id)).eq("is_delete", 0)).last("limit 1")), "当前分类正被使用中,不能删除！", new Object[0]);
      albumCate.setIsDelete(1);
      albumCate.setDeleteTime(System.currentTimeMillis() / 1000L);
      this.albumCateMapper.updateById(albumCate);
   }
}
